@@ -1,11 +1,11 @@
 context("miscellaneous")
 
-# .get_refdist() ----------------------------------------------------------
+# get_refdist() ----------------------------------------------------------
 
 ## ndraws and nclusters ---------------------------------------------------
 
 test_that(paste(
-  ".get_refdist(): `ndraws = NULL` and `nclusters = NULL` leads to",
+  "get_refdist(): `ndraws = NULL` and `nclusters = NULL` leads to",
   "`ndraws = S` (and `nclusters = NULL`)"
 ), {
   if (exists(".Random.seed", envir = .GlobalEnv)) {
@@ -13,14 +13,21 @@ test_that(paste(
   }
   set.seed(seed2_tst)
   for (tstsetup in names(refmods)) {
-    refdist <- .get_refdist(refmods[[tstsetup]])
+    refdist <- get_refdist(refmods[[tstsetup]])
+    if (args_ref[[tstsetup]]$prj_nm == "augdat") {
+      nobsv_fac <- length(refmods[[tstsetup]]$family$cats)
+    } else {
+      nobsv_fac <- 1L
+    }
     # The following refdist_tester() call runs more expectations than necessary
     # for this test (only the one for `refdist$clust_used` and the dim() test
     # for `refdist$mu` are actually necessary):
     refdist_tester(
       refdist,
+      nobsv_expected = nobsv * nobsv_fac,
       nprjdraws_expected = nrefdraws,
       clust_expected = FALSE,
+      fam_expected = refmods[[tstsetup]]$family$family,
       info_str = tstsetup
     )
   }
@@ -38,13 +45,20 @@ test_that(paste(
   for (tstsetup in names(refmods)) {
     for (ndraws_crr in list(nrefdraws + 1L)) {
       for (nclusters_crr in list(NULL, nrefdraws + 1L)) {
-        refdist <- .get_refdist(refmods[[tstsetup]],
-                                ndraws = ndraws_crr,
-                                nclusters = nclusters_crr)
+        refdist <- get_refdist(refmods[[tstsetup]],
+                               ndraws = ndraws_crr,
+                               nclusters = nclusters_crr)
+        if (args_ref[[tstsetup]]$prj_nm == "augdat") {
+          nobsv_fac <- length(refmods[[tstsetup]]$family$cats)
+        } else {
+          nobsv_fac <- 1L
+        }
         refdist_tester(
           refdist,
+          nobsv_expected = nobsv * nobsv_fac,
           nprjdraws_expected = nrefdraws,
           clust_expected = FALSE,
+          fam_expected = refmods[[tstsetup]]$family$family,
           info_str = paste(tstsetup, ndraws_crr, nclusters_crr, sep = "__")
         )
       }
@@ -73,10 +87,7 @@ test_that("rstanarm: special formulas work", {
     } else {
       expect_false(is.null(mf_spclformul), info = tstsetup)
     }
-    nms_spclformul <- setdiff(
-      grep("y_|xco", names(mf_spclformul), value = TRUE),
-      "xco.1"
-    )
+    nms_spclformul <- grep("y_|xco", names(mf_spclformul), value = TRUE)
 
     tstsetup_stdformul <- sub("\\.spclformul", ".stdformul", tstsetup)
     stopifnot(tstsetup_stdformul != tstsetup)
@@ -88,10 +99,7 @@ test_that("rstanarm: special formulas work", {
       } else {
         expect_false(is.null(mf_stdformul), info = tstsetup_stdformul)
       }
-      nms_stdformul <- setdiff(
-        grep("y_|xco", names(mf_stdformul), value = TRUE),
-        "xco.1"
-      )
+      nms_stdformul <- grep("y_|xco", names(mf_stdformul), value = TRUE)
       expect_equal(mf_spclformul[, setdiff(names(mf_spclformul),
                                            nms_spclformul)],
                    mf_stdformul[, setdiff(names(mf_stdformul),
@@ -113,7 +121,7 @@ test_that(paste(
   "`pseudo_data(f = 0, [...], family = extend_family(gaussian()), [...])` is",
   "essentially an identity function (apart from offsets)."
 ), {
-  mu_crr <- matrix(1:12, nrow = 3)
+  mu_crr <- matrix(1:3, ncol = 1)
   wobs_crr <- c(2.5, 6, 4)
   offs_crr <- c(-4.2, 3.5, 1.1)
   psdat <- pseudo_data(
